@@ -3,6 +3,8 @@ from .tfim_magnetization import tfim_magnetization
 from .tfim_square_magnetization import tfim_square_magnetization
 from .maxcut_tfim import maxcut_tfim
 from .maxcut_tfim_sparse import maxcut_tfim_sparse
+from .maxcut_tfim_streaming import maxcut_tfim_streaming
 from .spin_glass_solver import spin_glass_solver
 from .spin_glass_solver_sparse import spin_glass_solver_sparse
+from .spin_glass_solver_streaming import spin_glass_solver_streaming
 from .tsp import tsp_symmetric, tsp_asymmetric
