@@ -15,7 +15,7 @@ except ImportError:
 
 @njit
 def probability_by_hamming_weight(J, h, z, theta, t, n_qubits):
-    bias = np.empty(n_qubits - 1, dtype=np.float64)
+    bias = np.empty(n_qubits - 1, dtype=np.float32)
 
     # critical angle
     theta_c = np.arcsin(max(-1.0, min(1.0, abs(h) / (z * J))))
@@ -56,7 +56,7 @@ def maxcut_hamming_cdf(n_qubits, J_func, degrees, quality, hamming_prob):
     h_mult = 2.0 / tot_t
     n_bias = n_qubits - 1
 
-    theta = np.empty(n_qubits, dtype=np.float64)
+    theta = np.empty(n_qubits, dtype=np.float32)
     for q in range(n_qubits):
         J = J_func[q]
         z = degrees[q]
@@ -198,7 +198,7 @@ def sample_for_solution(G_data, G_rows, G_cols, shots, thresholds, J_eff):
     weights = 1.0 / (1.0 + (2 ** -52) - J_eff)
 
     solutions = np.empty((shots, n), dtype=np.bool_)
-    energies = np.empty(shots, dtype=np.float64)
+    energies = np.empty(shots, dtype=np.float32)
 
     for s in prange(shots):
         # First dimension: Hamming weight
@@ -225,13 +225,12 @@ def sample_for_solution(G_data, G_rows, G_cols, shots, thresholds, J_eff):
     return best_solution, best_value
 
 
-@njit
+@njit(parallel=True)
 def init_J_and_z(G_data, G_rows, G_cols):
     n_qubits = G_rows.shape[0] - 1
     degrees = np.empty(n_qubits, dtype=np.uint32)
-    J_eff = np.empty(n_qubits, dtype=np.float64)
-    J_max = -float("inf")
-    for r in range(n_qubits):
+    J_eff = np.empty(n_qubits, dtype=np.float32)
+    for r in prange(n_qubits):
         # Row sum
         start = G_rows[r]
         end = G_rows[r + 1]
@@ -248,21 +247,22 @@ def init_J_and_z(G_data, G_rows, G_cols):
             degrees[c] += 1
             J_eff[c] += G_data[idx]
 
-    for r in range(n_qubits):
+    J_max = -float("inf")
+    for r in prange(n_qubits):
         J = J_eff[r]
         degree = degrees[r]
         J_eff[r] = -J / degree if degree > 0 else 0
         J_abs = abs(J)
-        if J_abs > J_max:
-            J_max = J_abs
+        J_max = max(J_abs, J_max)
     J_eff /= J_max
 
     return J_eff, degrees
 
+
 @njit
 def init_thresholds(n_qubits):
     n_bias = n_qubits - 1
-    thresholds = np.empty(n_bias, dtype=np.float64)
+    thresholds = np.empty(n_bias, dtype=np.float32)
     tot_prob = 0
     p = 1.0
     if n_qubits & 1:
@@ -280,10 +280,10 @@ def init_thresholds(n_qubits):
     return thresholds
 
 
-@njit
+@njit(parallel=True)
 def init_theta(delta_t, tot_t, h_mult, n_qubits, J_eff, degrees):
-    theta = np.empty(n_qubits, dtype=np.float64)
-    for q in range(n_qubits):
+    theta = np.empty(n_qubits, dtype=np.float32)
+    for q in prange(n_qubits):
         J = J_eff[q]
         z = degrees[q]
         theta[q] = np.arcsin(
@@ -300,7 +300,7 @@ def init_theta(delta_t, tot_t, h_mult, n_qubits, J_eff, degrees):
 
 
 def to_scipy_sparse_upper_triangular(G, nodes, n_nodes):
-    lil = lil_matrix((n_nodes, n_nodes), dtype=np.float64)
+    lil = lil_matrix((n_nodes, n_nodes), dtype=np.float32)
     for u in range(n_nodes):
         u_node = nodes[u]
         for v in range(u + 1, n_nodes):
